@@ -36,7 +36,7 @@
 
 #include "extensions/extensions.h"
 
-#include "caps-channel-manager.h"
+#include "gabble/caps-channel-manager.h"
 #include "connection.h"
 #include "debug.h"
 #include "disco.h"
