@@ -26,7 +26,9 @@ CHANNEL_IFACE_PASSWORD = CHANNEL + ".Interface.Password"
 CHANNEL_IFACE_TUBE = CHANNEL + ".Interface.Tube"
 CHANNEL_IFACE_SASL_AUTH = CHANNEL + ".Interface.SASLAuthentication"
 CHANNEL_IFACE_CONFERENCE = CHANNEL + '.Interface.Conference'
-CHANNEL_IFACE_ROOM = CHANNEL + '.Interface.Room.DRAFT'
+CHANNEL_IFACE_ROOM = CHANNEL + '.Interface.Room2'
+CHANNEL_IFACE_ROOM_CONFIG = CHANNEL + '.Interface.RoomConfig1'
+CHANNEL_IFACE_SUBJECT = CHANNEL + '.Interface.Subject2'
 
 CHANNEL_TYPE_CALL = CHANNEL + ".Type.Call.DRAFT"
 CHANNEL_TYPE_CONTACT_LIST = CHANNEL + ".Type.ContactList"
@@ -453,6 +455,10 @@ MEDIA_STREAM_ERROR_MEDIA_ERROR = 7
 PASSWORD_FLAG_PROVIDE = 8
 
 # Channel.Interface.Room
-ROOM_ROOM_ID = CHANNEL_IFACE_ROOM + '.RoomID'
+ROOM_NAME = CHANNEL_IFACE_ROOM + '.RoomName'
 ROOM_SERVER = CHANNEL_IFACE_ROOM + '.Server'
-ROOM_SUBJECT = CHANNEL_IFACE_ROOM + '.Subject'
+
+# Channel.Interface.Subject
+SUBJECT = CHANNEL_IFACE_ROOM + '.Subject'
+SUBJECT_PRESENT = 1
+SUBJECT_CAN_SET = 2
